.. _waiverdb:

========
waiverdb
========

Synopsis
========

``waiverdb [OPTIONS]``

Description
===========

**waiverdb** is CLI tool managing WaiverDB server application.

Options
=======

.. option:: wait_for_db

    Wait until database server is reachable.
